@@ -13,7 +13,7 @@ from .low_density_identification import (
     low_density_identification_z_scores,
 )
 from .negative_running_hours import negative_running_hours_check
-from .outliers import extreme
+from .outliers import extreme, out_of_range
 from .rolling_stddev import rolling_stddev_timedelta
 from .uncertainty import uncertainty_rstd
 
@@ -30,6 +30,7 @@ __all__ = [
     "low_density_identification_threshold",
     "low_density_identification_z_scores",
     "extreme",
+    "out_of_range",
     "negative_running_hours_check",
     "uncertainty_rstd",
     "rolling_stddev_timedelta",
