@@ -13,6 +13,15 @@ from indsl.validations import validate_series_has_time_index
 
 
 class DataQualityScore:
+    """Data class storing the result of an event data quality analysis.
+
+    Attributes:
+        analysis_start: Analysis start time
+        analysis_end: Analysis end time
+        events: List of event events
+            Represented as pairs of timestamps
+    """
+
     @check_types
     def __init__(
         self,
@@ -20,7 +29,7 @@ class DataQualityScore:
         analysis_end: pd.Timestamp,
         events: List[Tuple[pd.Timestamp, pd.Timestamp]],
     ):
-        """Data class storing the result of a event data quality analysis
+        """Data quality score init function.
 
         Args:
             analysis_start: Analysis start time
@@ -44,7 +53,7 @@ class DataQualityScore:
 
     @property
     def degradation(self):
-        """Degradation factors"""
+        """Degradation factors."""
         return [
             (event_end - event_start) / (self.analysis_end - self.analysis_start)
             for event_start, event_end in self.events
@@ -52,11 +61,11 @@ class DataQualityScore:
 
     @property
     def score(self) -> float:
-        """Data quality score calculated as 1-sum(degradation)"""
+        """Data quality score calculated as 1-sum(degradation)."""
         return 1.0 - sum(self.degradation)
 
     def __add__(self, other: DataQualityScore) -> DataQualityScore:
-        """Return the union of two data quality results
+        """Return the union of two data quality results.
 
         Args:
             other: Other event data quality result
@@ -97,8 +106,14 @@ class DataQualityScore:
 
 
 class DataQualityScoreAnalyser(ABC):
+    """Object to calculate data quality scores.
+
+    Attributes:
+        series: time series
+    """
+
     def __init__(self, series: pd.Series):
-        """Object to calculate data quality scores
+        """Data quality score analyser init function.
 
         Args:
             series: time series
@@ -112,7 +127,7 @@ class DataQualityScoreAnalyser(ABC):
 
     @abstractmethod
     def compute_score(self, analysis_start: pd.Timestamp, analysis_end: pd.Timestamp) -> DataQualityScore:
-        """Compute data quality result
+        """Compute data quality result.
 
         Args:
             analysis_start: analyis start time
@@ -121,7 +136,7 @@ class DataQualityScoreAnalyser(ABC):
         Returns:
             DataQualityScore: A DataQualityScore object
 
-        raises:
+        Raises:
             UserValueError: If analysis_start < analysis_end
             UserValueError: If the analysis start and end timestamps are outside the range of the series index
         """
