@@ -35,6 +35,7 @@ class Cusum:
         https://nbviewer.org/github/demotu/detecta/blob/master/docs/detect_cusum.ipynb
     """
 
+    @check_types
     def __init__(
         self,
         data: pd.Series,
@@ -103,6 +104,7 @@ class Cusum:
         if not self.data.index.is_monotonic_increasing:
             raise UserValueError("Time series index is not increasing.")
 
+    @check_types
     def _detect_changes(self, endings: bool = False):
         """Detection of change points.
 
@@ -171,9 +173,7 @@ class Cusum:
         else:
             self.time_alarm_final = self.data.values.size - time_alarm_initial[::-1] - 1
 
-    def _detect_ending(
-        self,
-    ):
+    def _detect_ending(self):
         """Estimation of when the change ends (offline form)."""
         self._detect_changes(endings=True)
 
