@@ -57,7 +57,7 @@ def ssd_cpd(
     # the maximum allowable distance is half the number of datapoints
     max_distance: int = int(np.floor(len(x) / 2))
     if min_distance > max_distance:
-        raise RuntimeError(
+        raise UserValueError(
             f"min_distance ({min_distance}) is larger than the maximum allowable distance ({max_distance})"
         )
 
@@ -106,7 +106,9 @@ def ssd_cpd(
 
 
 @check_types
-def ssid(data: pd.Series, ratio_lim: float = 2.5, alpha1: float = 0.2, alpha2: float = 0.1, alpha3: float = 0.1):
+def ssid(
+    data: pd.Series, ratio_lim: float = 2.5, alpha1: float = 0.2, alpha2: float = 0.1, alpha3: float = 0.1
+) -> pd.Series:
     """Steady state (variance).
 
     The steady state detector is based on the ration of two variances estimated from the same signal [#]_ . The algorithm first
@@ -217,7 +219,7 @@ def vma(series: pd.Series, window_length: int = 10) -> pd.Series:
 
 
 @numba.njit
-def _estimate_iS(diff, k, N):
+def _estimate_iS(diff: np.ndarray, k: float, N: int) -> np.ndarray:
     # Estimate pdm and mdm:
     pdm, mdm = np.zeros(N), np.zeros(N)
     pdm[1:] = np.maximum(diff, 0)
@@ -246,7 +248,7 @@ def _estimate_iS(diff, k, N):
 
 
 @numba.njit
-def _estimate_vma(vI, arr, k, N):
+def _estimate_vma(vI: np.ndarray, arr: np.ndarray, k: float, N: int):
     vma = np.zeros(N)
     for i in range(1, N):
         vma[i] = (1 - k * vI[i]) * vma[i - 1] + k * vI[i] * arr[i]
