@@ -10,10 +10,9 @@ from indsl.validations import validate_series_has_time_index, validate_series_is
 def unchanged_signal_detector(
     data: pd.Series, duration: pd.Timedelta = pd.Timedelta(minutes=60), min_nr_data_points: int = 3
 ) -> pd.Series:
-    """Unchanged signal detection
+    """Unchanged signal detection.
 
     Detect periods of time when the data stays at a constant value for longer than a given time window.
-    duration threshold.
 
     Args:
         data: Time series.
@@ -31,7 +30,6 @@ def unchanged_signal_detector(
         UserTypeError: data is not a time series
         UserValueError: data is empty
     """
-
     validate_series_has_time_index(data)
     validate_series_is_not_empty(data)
 
