@@ -5,7 +5,7 @@ from indsl.type_check import check_types
 
 
 @check_types
-def Re(speed: pd.Series, density: float, d_viscosity: float, length_scale: float):
+def Re(speed: pd.Series, density: float, d_viscosity: float, length_scale: float) -> pd.Series:
     """Reynolds Number.
 
     The Reynolds number is the ratio of inertial forces to viscous forces within a fluid subjected to
