@@ -6,11 +6,14 @@ import pandas as pd
 
 from statsmodels.tsa.holtwinters import ExponentialSmoothing
 
+from indsl import versioning
+
 from ..exceptions import UserRuntimeError, UserValueError
 from ..type_check import check_types
 from ..validations import validate_series_has_time_index
 
 
+@versioning.register(version="1.0", deprecated=True)
 @check_types
 def holt_winters_predictor(
     data: pd.Series,
@@ -75,7 +78,7 @@ def holt_winters_predictor(
 
     n_obs = len(data)
     n_train = int(n_obs * train_fraction)
-    dt_step_sec = data.reset_index()["index"].diff().mean().total_seconds()
+    dt_step_sec = int(data.reset_index()["index"].diff().mean().total_seconds())
 
     train_data = data.iloc[:n_train]
     pred_data = _train_and_return_forecast(
@@ -85,6 +88,7 @@ def holt_winters_predictor(
     return pred_data.dropna()
 
 
+@check_types
 def _train_and_return_forecast(
     train_data: pd.Series,
     seasonality: str,
@@ -93,7 +97,7 @@ def _train_and_return_forecast(
     dampen_trend: bool,
     steps: int,
     dt_step_sec: int,
-):
+) -> pd.Series:
     """Train and return forecast.
 
     Function to train an Holt-Winters model and return the forecasted value
