@@ -5,7 +5,7 @@ from indsl.versioning import register
 
 
 @register(version="1.0", deprecated=True, changelog="Intended for CHARTS internal use only")
-def no_op(series: pd.Series):
+def no_op(series: pd.Series) -> pd.Series:
     """Identity operator.
 
     Return the input unmodified as output.
