@@ -1,31 +1,33 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 import operator as op
 import warnings
 
-from enum import Enum
 from typing import Literal, Optional
 
 import pandas as pd
 
 from scipy import signal
 
+from indsl import versioning
+from indsl.exceptions import UserTypeError
 from indsl.ts_utils.ts_utils import fill_gaps, get_fixed_freq, is_na_all
+from indsl.type_check import check_types
+from indsl.validations import validate_series_has_time_index, validate_series_is_not_empty
 
-from ..exceptions import UserTypeError, UserValueError
-from ..type_check import check_types
-from ..validations import validate_series_has_time_index
+from . import resample_v1  # noqa
 
 
+@versioning.register(version="2.0", changelog="update data types")
 @check_types
 def resample(
     data: pd.Series,
     method: Literal["fourier", "polyphase", "interpolate", "min", "max", "sum", "count", "mean"] = "fourier",
-    granularity_current: Optional[str] = None,
-    granularity_next: str = "1s",
+    granularity_current: Optional[pd.Timedelta] = None,
+    granularity_next: Optional[pd.Timedelta] = pd.Timedelta("1s"),
     num: Optional[int] = None,
     downsampling_factor: Optional[int] = None,
-    interpolate_resolution: Optional[str] = None,
-    ffill_resolution: Optional[str] = None,
+    interpolate_resolution: Optional[pd.Timedelta] = None,
+    ffill_resolution: Optional[pd.Timedelta] = None,
 ) -> pd.Series:
     """Resample.
 
@@ -41,7 +43,7 @@ def resample(
         data: Time series.
 
         method: Method.
-            Resampling method:
+            Resampling method. Valid options are:
 
                 * "fourier" for Fourier method (default)
                 * "polyphase" for polyphase filtering
@@ -84,13 +86,12 @@ def resample(
         UserTypeError: All values in the time series are NaN
         Warning: Can't infer time series resolution with missing data. Please provide resolution
     """
-    if not granularity_next and (not num or num <= 0):
+    if granularity_next is None and (num is None or num <= 0):
         raise UserTypeError("Either num or granularity_next has to be set.")
 
     validate_series_has_time_index(data)
-    if len(data) == 0:
-        raise UserValueError(f"Expected data to be of length > 0, got length {len(data)}")
-    elif is_na_all(data):
+    validate_series_is_not_empty(data)
+    if is_na_all(data):
         raise UserTypeError("All values in the time series are NaN.")
 
     # To resample data to uniform distribution
@@ -101,7 +102,7 @@ def resample(
         if not granularity_current:
             # TODO: pick max resolution and apply to the rest of the timeseries?
             warnings.warn(
-                "Can't infer time series resolution with missing data. Please provide resolution", RuntimeWarning
+                "Can't infer time series resolution with missing data. Please provide resolution", UserWarning
             )
             return data
 
@@ -122,7 +123,7 @@ def resample(
     )
 
     if not num:
-        num = 1 + int((data.index.max() - data.index.min()) / pd.Timedelta(granularity_next))
+        num = 1 + int((data.index.max() - data.index.min()) / granularity_next)
 
     if method == "fourier":
         series = pd.Series(signal.resample(data, num), index=pd.date_range(data.index.min(), data.index.max(), num))
@@ -140,19 +141,12 @@ def resample(
     return series
 
 
-class AggregateEnum(Enum):  # noqa
-    MEAN = "mean"
-    INTERPOLATION = "interpolation"
-    STEP_INTERPOLATION = "stepInterpolation"
-    MAX = "max"
-    MIN = "min"
-    COUNT = "count"
-    SUM = "sum"
-
-
+@versioning.register(version="2.0", changelog="Describe here how the function changed compared to the previous version")
 @check_types
 def resample_to_granularity(
-    series: pd.Series, granularity: str = "1h", aggregate: AggregateEnum = AggregateEnum.MEAN
+    series: pd.Series,
+    granularity: pd.Timedelta = pd.Timedelta("1h"),
+    aggregate: Literal["mean", "interpolation", "stepInterpolation", "max", "min", "count", "sum"] = "mean",
 ) -> pd.Series:
     """Resample to granularity.
 
@@ -168,39 +162,36 @@ def resample_to_granularity(
             time range should be 2 hours wide, 3m means 3 minutes, and so on.
 
         aggregate: Aggregate.
-            Type of aggregation to use when resampling. Possible options are:
+            Type of aggregation to use when resampling. Valid options are:
 
-                * mean
-                * max
-                * min
-                * count
-                * sum
+                * "interpolate" for linear interpolation when upsampling
+                * "stepInterpolation" for stepwise interpolation when upsampling
+                * "min", "max", "sum", "count", "mean" when downsampling
 
     Returns:
         pandas.Series: Resampled time series.
     """
     validate_series_has_time_index(series)
-    if len(series) == 0:
-        raise UserValueError(f"Expected series to be of length > 0, got length {len(series)}")
+    validate_series_is_not_empty(series)
 
     # Translates from cdf aggregates to pandas method names:
     # TODO: 'mean' (point-weighted) does not equal CDF average (time-weighted).
     # Read more in the docs: https://docs.cognite.com/dev/concepts/aggregation/
     start_time = series.index[0]
     end_time = series.index[-1]
-    if aggregate in (AggregateEnum.MIN, AggregateEnum.MAX, AggregateEnum.SUM, AggregateEnum.COUNT, AggregateEnum.MEAN):
-        series = series.resample(granularity.replace("m", "T"), origin="epoch")
-        series = op.methodcaller(aggregate.value)(series)
-        if aggregate is AggregateEnum.MEAN:
+    if aggregate in ("min", "max", "sum", "count", "mean"):
+        resampler = series.resample(granularity, origin="epoch")
+        series_out = op.methodcaller(aggregate)(resampler)
+        if aggregate == "mean":
             # We only fill inner holes with lin.interp for average:
-            series = series.interpolate("slinear")
-        return series.dropna()
+            series_out = series_out.interpolate("slinear")
+        return series_out.dropna()
 
-    elif aggregate in (AggregateEnum.INTERPOLATION, AggregateEnum.STEP_INTERPOLATION):
+    elif aggregate in ("interpolation", "stepInterpolation"):
         # We adhere to the CDF definition of interp. and step interp:
         fixed_freq = get_fixed_freq(start_time, end_time, granularity)
         series = series.reindex(series.index.union(fixed_freq))  # Note: reindex, not resample
-        if aggregate is AggregateEnum.INTERPOLATION:
+        if aggregate == "interpolation":
             return series.interpolate("slinear")[fixed_freq].dropna()
         else:
             return series.ffill().bfill()[fixed_freq]
