@@ -1,12 +1,10 @@
 import warnings
 
-from typing import List, Literal, Optional
+from typing import Any, List, Literal, Optional, Union
 
 import numpy as np
 import pandas as pd
 
-from indsl.ts_utils.utility_functions import TimeUnits
-
 from ..exceptions import UserValueError
 from ..type_check import check_types
 from ..validations import validate_series_has_time_index
@@ -32,7 +30,7 @@ def line(
         end_date: End date.
             The end date of the time series entered as a string, for example: "1975-05-09 20:09:10", or
             "1975-05-09".
-        sample_freq: Frequency
+        sample_freq: Frequency.
             Sampling frequency as a time delta, value and time unit. Defaults to '1 minute'. Valid time units are:
 
                 * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
@@ -43,9 +41,9 @@ def line(
                 * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
                 * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
                 * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
-        slope: Slope
+        slope: Slope.
             Line slope. Defaults to 0 (horizontal line).
-        intercept: Intercept
+        intercept: Intercept.
              Y-intercept. Defaults to 0.
 
     Returns:
@@ -64,15 +62,15 @@ def const_value(value: float = 0, timedelta: pd.Timedelta = pd.Timedelta("1 W"))
     """Constant value.
 
     This function generates a horizontal line. The assumptions when generating the horizontal line
-    is that the start date is set as "1970-01-01", the end date is set as "now" and the sampling is "1 week".
-    If the number of data points generated exceeds 100000 then the start date is moved forward, such that the
+    are that the start date is set as "1970-01-01", the end date is set as "now", and the sampling is "1 week".
+    If the number of data points generated exceeds 100000, then the start date is moved forward, such that the
     number of data points generated is not greater than 100000 with "1 week" sampling resolution.
 
     Args:
         value: Value.
             value. Defaults to 0.
         timedelta: Granularity.
-            Sampling frequency as a time delta, value and time unit. Defaults to one week ('1 W'). Valid time units are:
+            Sampling frequency as a time delta, value, and time unit. Defaults to one week ('1 W'). Valid time units are:
 
                 * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
                 * ‘days’ or ‘day’
@@ -97,6 +95,7 @@ def const_value(value: float = 0, timedelta: pd.Timedelta = pd.Timedelta("1 W"))
     return pd.Series(data=line_data, index=idx, name="Constant value")
 
 
+@check_types
 def sine_wave(
     start_date: Optional[pd.Timestamp] = None,
     end_date: Optional[pd.Timestamp] = None,
@@ -109,7 +108,7 @@ def sine_wave(
     """Sine wave.
 
     Generate a time series for a `sine wave <https://en.wikipedia.org/wiki/Sine_wave>`_ with a given wave period,
-    amplitude, phase and mean value. If no end and/or start dates are given, the default signal duration is set to
+    amplitude, phase, and mean value. If no end and/or start dates are given, the default signal duration is set to
     1 day. If no dates are provided, the end date is set to the current date and time.
 
     Args:
@@ -119,8 +118,8 @@ def sine_wave(
         end_date: End date
             Date-time string when the time series starts. The date must be a string, for example:
             "1975-05-09 20:09:10".
-        sample_freq: Frequency
-            Sampling frequency as a time delta, value and time unit. Defaults to '1 minute'. Valid time units are:
+        sample_freq: Frequency.
+            Sampling frequency as a time delta, value, and time unit. Defaults to '1 minute'. Valid time units are:
 
                 * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
                 * ‘days’ or ‘day’
@@ -130,10 +129,10 @@ def sine_wave(
                 * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
                 * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
                 * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
-        wave_period: Wave period
+        wave_period: Wave period.
             The time it takes for two successive crests (one wavelength) to pass a specified point. For example, defining
             a wave period of :math:`10 min` will generate one full wave every 10 minutes. The period can not be 0. If
-            no value is provided, it 1 minute. Valid time units are:
+            no value is provided, it is 1 minute. Valid time units are:
 
                 * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
                 * ‘days’ or ‘day’
@@ -143,11 +142,11 @@ def sine_wave(
                 * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
                 * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
                 * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
-        wave_mean: Mean
+        wave_mean: Mean.
             The wave's mean value. Defaults to 0.
-        wave_amplitude: Peak amplitude
+        wave_amplitude: Peak amplitude.
             Maximum absolute deviation from the mean. Defaults to 1.
-        wave_phase: Phase
+        wave_phase: Phase.
             Specifies (in radians) where in its cycle the oscillation is at time = 0. When the phase is non-zero, the
             wave is shifted in time. A negative value represents a delay, and a positive value represents an advance.
             Defualts to 0.
@@ -173,32 +172,6 @@ def sine_wave(
     return pd.Series(data=wave_data, index=idx, name="Sine wave")
 
 
-def _get_sample_frequency(sample_freq: float, unit: TimeUnits):
-    """Get sample frequency.
-
-    Helper method to convert the frequency magnitude and units into a string that is then used by other function
-    to generate DatetimeIndex data
-    Args:
-        sample_freq: Frequency magnitude
-        unit: Time unit
-            Valid values "ns|us|ms|s|m|h|D|W". Default is "m" (minutes)
-
-    Returns:
-        str: Frequency string
-
-    """
-    if unit == "m":
-        use_unit = "min"
-    elif unit == "s":
-        use_unit = "S"
-    elif unit == "W":
-        use_unit = "D"
-        sample_freq = sample_freq * 7
-    else:
-        use_unit = unit
-    return pd.Timedelta(sample_freq, use_unit)
-
-
 @check_types
 def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
     """Perturb timestamp.
@@ -208,9 +181,8 @@ def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
 
     Args:
         data: Time series
-        magnitude: Magnitude
-            Time delta perturbation magnitude in seconds. If none is given, it is set to the inferred average sampling
-            rate in seconds of the original signal.
+        magnitude: Magnitude.
+            Time delta perturbation magnitude in seconds. Has to be large than 0. Defaults to 1.
 
     Returns:
         pandas.Series: Time series
@@ -219,9 +191,12 @@ def perturb_timestamp(data: pd.Series, magnitude: float = 1) -> pd.Series:
     Raises:
         UserTypeError: Only time series with a DateTimeIndex are supported
         UserTypeError: If "magnitude" is not a float
+        UserValueError: If "magnitude" is not larger than 0
 
     """
     validate_series_has_time_index(data)
+    if magnitude <= 0:
+        raise UserValueError(f"Expected magnitude to be > 0, got {magnitude}")
 
     time = _time_array(data.index)
 
@@ -247,17 +222,17 @@ def insert_data_gaps(
 ) -> pd.Series:
     """Insert data gaps.
 
-    Method to synthetically remove data, i.e. generate data gaps in a time series. The amount of data points removed
+    Method to synthetically remove data, i.e., generate data gaps in a time series. The amount of data points removed
     is defined by the given 'fraction' relative to the original time series.
 
     Args:
         data: Time series
-        fraction: Remove fraction
+        fraction: Remove fraction.
             Fraction of data points to remove relative to the original time series. Must be a number higher than 0 and
             lower than 1 (0 < keep < 1). Defaults to 0.25.
-        num_gaps: Number of gaps
+        num_gaps: Number of gaps.
             Number of gaps to generate. Only needs to be provided when using the "Multiple" gaps method.
-        data_buffer: Buffer
+        data_buffer: Buffer.
             Minimum of data points to keep between data gaps and at the start and end of the time series. If the buffer
             of data points is higher than 1% of the number of data points in the time series, the end and start buffer
             is set to 1% of the total available data points.
@@ -274,8 +249,7 @@ def insert_data_gaps(
                   buffer is set to the maximum value between 5 data points or 1% of the data points in the signal.
                 * Multiple: Insert multiple non-overlapping data gaps at random dates and of random
                   sizes such that the given fraction of data is removed. If the number of gaps is not defined or is
-                  less than 2, the function defaults to 2 gaps. To avoid gap overlapping, a minimum of 5 data points
-                  is imposed at the start and end of the signal and between gaps.
+                  less than 2, the function defaults to 2 gaps. To avoid gap overlapping, a minimum of 5 data points are imposed at the signal's start and end and between gaps.
 
     Returns:
         pandas.Series: Output
@@ -336,7 +310,8 @@ def insert_data_gaps(
         return data.drop(labels=idx)
 
 
-def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int = 5):
+@check_types
+def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int = 5) -> np.ndarray:
     """Handle overlapping gaps.
 
     Internal method to handle overlapping gaps. The method calculates the
@@ -358,7 +333,8 @@ def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int
             f"be (n,2), but we got {np.shape(gap_ranges)}"
         )
 
-    def _calculate_overlaps():
+    @check_types
+    def _calculate_overlaps() -> np.ndarray:
         """Calculate overlaps.
 
         Calculates the overlap between adjacent intervals as positive numbers and the space between intervals
@@ -446,6 +422,7 @@ def _handle_overlapping_gaps(gap_ranges: np.array, data_length: int, buffer: int
     return new_ranges
 
 
+@check_types
 def _time_array(index: pd.DatetimeIndex) -> np.array:
     """Get time array.
 
@@ -463,10 +440,11 @@ def _time_array(index: pd.DatetimeIndex) -> np.array:
     return (index - index[0]).view(np.int64) / 1e9
 
 
+@check_types
 def _make_index(
-    start: Optional[pd.Timestamp] = None,
-    end: Optional[pd.Timestamp] = None,
-    freq: Optional[pd.Timedelta] = pd.Timedelta(1, "m"),
+    start: Union[pd.Timedelta, pd.Timestamp, str, None] = None,
+    end: Union[pd.Timedelta, pd.Timestamp, str, None] = None,
+    freq: Any = pd.Timedelta(1, "m"),
 ) -> pd.DatetimeIndex:
     """Make datetime index.
 
@@ -515,6 +493,7 @@ def _make_index(
     return index
 
 
+@check_types
 def _random_list_of_integers_that_gives_exact_sum(list_length: int, sum_output: int) -> list:
     if list_length > sum_output:
         raise UserValueError(
