@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 import pandas as pd
 
 from statsmodels.tsa.arima.model import ARIMA
@@ -8,18 +8,18 @@ from ..validations import validate_series_is_not_empty
 
 
 @check_types
-def arma(data: pd.Series, ar_order: int = 2, ma_order: int = 2):
+def arma(data: pd.Series, ar_order: int = 2, ma_order: int = 2) -> pd.Series:
     """Autoregressive moving average.
 
     The autoregressive moving average (ARMA) is a popular model used in forecasting. It uses an autoregression (AR)
-    analysis characterize the effect of past values on current values and a moving average to quantify the effect of the
-    previous day error (variation).
+    analysis to characterize the effect of past values on current values and a moving average to quantify the effect of the
+    previous day's error (variation).
 
 
     Args:
         data: Time series.
         ar_order: AR order.
-            Number of past dat points to include in the AR model. Defaults to 2.
+            Number of past data points to include in the AR model. Defaults to 2.
         ma_order: MA order.
             Number of terms in the MA model.  Defaults to 2.
 
