@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 from typing import Literal
 
 import pandas as pd
@@ -8,7 +8,7 @@ from scipy.signal import butter, sosfilt
 from indsl import versioning
 from indsl.type_check import check_types
 
-from . import butterworth_  # noqa
+from . import butterworth_v1  # noqa
 
 
 # noinspection SpellCheckingInspection
@@ -23,13 +23,13 @@ def butterworth(
     N: int = 50,
     Wn: float = 0.1,
     btype: Literal["lowpass", "highpass"] = "lowpass",
-):
+) -> pd.Series:
     """Butterworth.
 
-    This is signal processing filter designed to have a frequency response as flat as possible in the passband and
+    This signal processing filter is designed to have a frequency response as flat as possible in the passband and
     roll-offs towards zero in the stopband. In other words, this filter is designed not to modify much the signal at the
-    in the passband and attenuate as much as possible the signal at the stopband. At the moment onlylow and high pass
-    filtering is supported.
+    in the passband and attenuate as much as possible the signal at the stopband. At the moment, only low and high pass
+    filtering are supported.
 
     Args:
         data: Time series.
@@ -46,6 +46,10 @@ def butterworth(
         pandas.Series: Filtered signal.
     """
     data = data.dropna()
+
+    if len(data) < 1:
+        return data
+
     filter_output = butter(N=N, Wn=Wn, output="sos", btype=btype)
     # Apply second order segments
     filtered = sosfilt(filter_output, data, axis=0)
