@@ -1,23 +1,28 @@
 # Copyright 2021 Cognite AS
+from typing import Optional
+
 import numpy as np
 import pandas as pd
 
 from numba import jit
 
-from ..ts_utils.ts_utils import time_parse
+from indsl import versioning
+
 from ..type_check import check_types
 from ..validations import validate_series_is_not_empty
+from . import eweight_ma_v1  # noqa
 
 
+@versioning.register(version="2.0", changelog="Update parameter type")
 @check_types
 def ewma(
     data: pd.Series,
-    time_window: str = "60min",
+    time_window: pd.Timedelta = pd.Timedelta("60min"),
     min_periods: int = 1,
     adjust: bool = True,
     max_pt: int = 200,
     resample: bool = False,
-    resample_window: str = "60min",
+    resample_window: pd.Timedelta = pd.Timedelta("60min"),
 ) -> pd.Series:
     """Exp. weighted moving average.
 
@@ -31,7 +36,6 @@ def ewma(
             Data with a pd.DatetimeIndex.
         time_window: Time window.
             Defines how important the current observation is in the calculation of the EWMA. The longer the period, the slowly it adjusts to reflect current trends. Defaults to '60min'.
-            If the user gives a number without unit (such as '60'), it will be considered as the number of minutes.
             Accepted string format: '3w', '10d', '5h', '30min', '10s'.
             The time window is converted to the number of points for each of the windows. Each time window may have different number of points if the timeseries is not regular.
             The number of points specify the decay of the exponential weights in terms of span α=2/(span+1), for span≥1.
@@ -53,7 +57,6 @@ def ewma(
     """
     validate_series_is_not_empty(data)
 
-    time_window = time_parse(time_window)
     win_pts_lst = np.array(data.rolling(time_window).count().values)
     ewma_vals = np.zeros_like(data)
     a = 2.0 / (win_pts_lst + 1)
@@ -70,21 +73,20 @@ def ewma(
     ewma_vals[bool_mask] = None
     ewma_series = pd.Series(ewma_vals, index=data.index)
     if resample:
-        resample_window = time_parse(resample_window)
         ewma_series = ewma_series.resample(resample_window).mean()
     return ewma_series
 
 
 @jit(nopython=True)  # @njit
-def ewma_pt_adjust(data, value, i, a, max_pt=200):
+def ewma_pt_adjust(data: np.ndarray, value: float, i: int, a: np.ndarray, max_pt: int = 200) -> float:
     """Calculates ewma value using weights wi=(1−a)^i.
 
     Args:
         data (numpy.ndarray): Data values of the time series.
         value (float): Current datapoint.
         i (int): Index of the current value.
-        a (float): Alpha value to compute ewma.
-        max_pt (int, optional): Maximum number of points to consider when calculating ewma. Defaults to 200.
+        a (np.ndarray): Alpha value to compute ewma.
+        max_pt (int): Maximum number of points to consider when calculating ewma. Defaults to 200.
 
     Returns:
         float: Calculated ewma for the current datapoint.
@@ -98,7 +100,9 @@ def ewma_pt_adjust(data, value, i, a, max_pt=200):
 
 
 # @jit(nopython=True)
-def ewma_pt_not_adjust(data, value, min_periods, ewma_vals, i, a):
+def ewma_pt_not_adjust(
+    data: np.ndarray, value: float, min_periods: int, ewma_vals: np.ndarray, i: int, a: np.ndarray
+) -> Optional[float]:
     """Calculates the ewma recursively using yt=(1−α)yt−1+αxt.
 
     Args:
@@ -108,9 +112,10 @@ def ewma_pt_not_adjust(data, value, min_periods, ewma_vals, i, a):
             If min_periods > 1 the SMA is computed for the first observation.
         ewma_vals (numpy.ndarray): Array of the ewma values.
         i (int): Index of the current value.
-        a (float): Alpha value to compute ewma.
+        a (np.ndarray): Alpha value to compute ewma.
 
     Returns:
+        None: Index of the current value is smaller than minimum number of observations in window required to have a value.
         float: Calculated ewma for the current datapoint.
     """
     if i < min_periods - 1:
