@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 import pandas as pd
 
 from scipy.signal import savgol_filter
@@ -13,21 +13,21 @@ from ..type_check import check_types
 def sg(data: pd.Series, window_length: int = None, polyorder: int = 1) -> pd.Series:
     """Saviztky-Golay.
 
-    Use this filter for smoothing data, without distorting the data tendency. The method is independent of
-    the sampling frequency, hence simple and robust to apply on data with non-uniform sampling. If working with
-    high-frequency data (e.g. sampling frequency ~> 1 Hz) we recommend the user to provide the filter window length and
+    Use this filter for smoothing data without distorting the data tendency. The method is independent of
+    the sampling frequency. Hence, it is simple and robust to apply to data with non-uniform sampling. If you work with
+    high-frequency data (e.g., sampling frequency ~> 1 Hz), we recommend that you provide the filter window length and
     polynomial order parameters to suit the requirements. Otherwise, if no parameters are provided, the function will
-    estimate and set the parameters based on the characteristics of the input time series (e.g. sampling frequency).
+    estimate and set the parameters based on the characteristics of the input time series (e.g., sampling frequency).
 
     Args:
         data: Time series.
         window_length: Window.
-            Point-wise length of the filter window (i.e. number of data points). A large window results in a stronger
+            Point-wise length of the filter window (i.e., number of data points). A large window results in a stronger
             smoothing effect and vice-versa. If the filter window_length is not defined by the user, a
             length of about 1/5 of the length of time series is set.
         polyorder: Polynomial order.
             Order of the polynomial used to fit the samples. Must be less than filter window length. Defaults to 1.
-            Hint: A small polyorder (e.g. polyorder = 1) results in a stronger data smoothing effect, representing the
+            Hint: A small polyorder (e.g., polyorder = 1) results in a stronger data smoothing effect, representing the
             dominating trend and attenuating data fluctuations.
 
     Returns:
