@@ -1,5 +1,6 @@
-# Copyright 2021 Cognite AS
-import warnings
+# Copyright 2022 Cognite AS
+
+from typing import Optional
 
 import numpy as np
 import pandas as pd
@@ -9,18 +10,25 @@ from kneed import KneeLocator
 from sklearn.cluster import DBSCAN
 from sklearn.neighbors import NearestNeighbors
 
+from indsl import versioning
 from indsl.exceptions import UserValueError
 from indsl.type_check import check_types
-from indsl.validations import validate_series_is_not_empty, validate_series_not_uniform_values
+from indsl.validations import validate_series_has_time_index, validate_series_is_not_empty
+
+from . import outliers_v1  # noqa
 
 
+@versioning.register(
+    version="2.0",
+    changelog="handles steady_state inputs without crashing, improves performance and implements new input types",
+)
 @check_types
 def detect_outliers(
     data: pd.Series,
     reg_smooth: float = 0.9,
     min_samples: int = 4,
-    eps: float = None,
-    time_window: str = "60min",
+    eps: Optional[float] = None,
+    time_window: pd.Timedelta = pd.Timedelta("60min"),
     del_zero_val: bool = False,
 ) -> pd.Series:
     """Outlier detection.
@@ -65,7 +73,7 @@ def detect_outliers(
         time_window: Time window.
             Length of the time period to compute the rolling mean. The rolling mean and the data point value are the two features considered when calculating the distance to the furthest neighbour.
             This distance allows us to find the right epsilon when training dbscan. Defaults to '60min'.
-            Accepted string format: '3w', '10d', '5h', '30min', '10s'.
+            Accepted format: '3w', '10d', '5h', '30min', '10s'.
             If a number without unit (such as '60')is given, it will be considered as the number of minutes.
         del_zero_val: Remove zeros.
             Removes data points containing a value of 0. Defaults to False.
@@ -93,13 +101,14 @@ def detect_outliers(
     return outlier_indicator_ts
 
 
+@versioning.register(version="2.0", changelog="handle steady_state inputs, better performance; new input types")
 @check_types
 def remove_outliers(
     data: pd.Series,
     reg_smooth: float = 0.9,
     min_samples: int = 4,
-    eps: float = None,
-    time_window: str = "60min",
+    eps: Optional[float] = None,
+    time_window: pd.Timedelta = pd.Timedelta("60min"),
     del_zero_val: bool = False,
 ) -> pd.Series:
     """Outlier removal.
@@ -143,7 +152,7 @@ def remove_outliers(
         time_window: Time window.
             Length of the time period to compute the rolling mean. The rolling mean and the data point value are the two features considered when calculating the distance to the furthest neighbour.
             This distance allows us to find the right epsilon when training dbscan. Defaults to '60min'.
-            Accepted string format: '3w', '10d', '5h', '30min', '10s'.
+            Accepted format: '3w', '10d', '5h', '30min', '10s'.
             If a number without unit (such as '60')is given, it will be considered as the number of minutes.
         del_zero_val: Remove zeros.
             Removes data points containing a value of 0. Defaults to False.
@@ -162,11 +171,11 @@ def remove_outliers(
 @check_types
 def _get_outlier_indices(
     data: pd.Series,
-    min_samples: int = 4,
-    eps: float = None,
-    time_window: str = "60min",
-    del_zero_val: bool = False,
-    reg_smooth: float = 0.9,
+    min_samples,
+    eps: Optional[float],
+    time_window: pd.Timedelta,
+    del_zero_val: bool,
+    reg_smooth: float,
 ) -> pd.DatetimeIndex:
     """Get outlier indices.
 
@@ -178,8 +187,7 @@ def _get_outlier_indices(
         min_samples: Minimum samples.
         eps: Distance threshold.
         time_window: Time window.
-            Defaults to '60min'.
-            Accepted string format: '3w', '10d', '5h', '30min', '10s'.
+            Accepted format: '3w', '10d', '5h', '30min', '10s'.
             If a number without unit (such as '60')is given, it will be considered as the number of minutes.
         del_zero_val: Remove zeros.
             Defaults to False.
@@ -187,41 +195,34 @@ def _get_outlier_indices(
     Returns:
         pandas.DatetimeIndex: An array of indices of outliers in the given time series.
     """
-    validate_series_not_uniform_values(data)
+    # Handle special cases
+    if len(data) <= 4:
+        return pd.DatetimeIndex([])
+    if (data.values == data.values[0]).all():  # if data is uniform, return 0 outliers
+        return pd.DatetimeIndex([])
+
+    # Validations
+    validate_series_has_time_index(data)
+
+    if eps is not None and eps <= 0.0:
+        raise UserValueError("eps should be > 0.0.")
 
     df = data.to_frame()
     df = df.rename(columns={df.columns[0]: "val"})
 
-    if str.isdigit(time_window):  # if user gives '60' it will be considered as '60min'
-        warnings.warn(
-            f"Missing time unit in argument 'time_window' in remove_outliers function, assuming {time_window}min.",
-            UserWarning,
-        )
-        time_window = str(time_window) + "min"
-
-    try:
-        time_window = pd.Timedelta(time_window)
-    except ValueError:
-        raise UserValueError(
-            f"Time window should be a string in weeks, days, hours or minutes format:'3w', '10d', '5h', '30min', '10s' not {time_window}."
-        ) from None
-
-    if eps == 0.0:
-        raise UserValueError("eps should be > 0.0.") from None
-
     df["rolling_mean"] = df["val"].rolling(time_window, min_periods=1).mean()  # calculate features
 
     if del_zero_val:  # delete 0 values if user requests it
         df = df[df["val"] != 0.0]
 
     df_dbscan = df[["val"]].copy()
-
     validate_series_is_not_empty(df_dbscan)
 
     if eps is None:
         # calculate distance to the further neighbor in order to find best epsilon (radius) parameter for dbscan
-        nbrs = NearestNeighbors(n_neighbors=2 * 3).fit(df)
-        distances, indices = nbrs.kneighbors(df)
+        n_neighbors = min(len(df) - 3, 6)
+        nbrs = NearestNeighbors(n_neighbors=n_neighbors).fit(df)
+        distances, _ = nbrs.kneighbors(df)
         df["knn_dist"] = distances[:, -1]
 
         dist = np.sort(distances[:, -1])
@@ -239,11 +240,11 @@ def _get_outlier_indices(
     outlier_indices_dbscan = df.iloc[outlier_positions].index
 
     # Delete outliers detected by dbscan
-    df_without_dbscan_outliers = df.drop(outlier_indices_dbscan).copy()
+    df_without_dbscan_outliers = df.drop(outlier_indices_dbscan)
 
     # Apply regression on the remaining data points
-    df_reg = df.loc[df_without_dbscan_outliers.index, :].copy()
-    date_int = df_reg.index.to_series().apply(lambda x: x.value)
+    df_reg = df.loc[df_without_dbscan_outliers.index, :]
+    date_int = df_reg.index.to_series().astype(np.int64)
     date_int_stand = (date_int - date_int.mean()) / date_int.std()
     csaps_data = csaps(date_int_stand, df_reg["val"], date_int_stand, smooth=reg_smooth)
 
@@ -262,4 +263,36 @@ def _get_outlier_indices(
     return all_outliers
 
 
+def outlier_percent(
+    data: pd.Series,
+    min_samples: int = 4,
+    eps: Optional[float] = None,
+    time_window: pd.Timedelta = pd.Timedelta("60min"),
+    del_zero_val: bool = False,
+    reg_smooth: float = 0.9,
+) -> Optional[float]:
+    """Calculates the percentage of outliers in the given time series.
+
+    Args:
+        data: Time series.
+        min_samples: Minimum samples.
+        eps: Distance threshold.
+        time_window: Time window.
+            Defaults to '60min'.
+            Accepted format: '3w', '10d', '5h', '30min', '10s'.
+            If a number without unit (such as '60')is given, it will be considered as the number of minutes.
+        del_zero_val: Remove zeros.
+            Defaults to False.
+        reg_smooth: Smoothing factor.
+
+    Returns:
+        float: Percentage of outliers.
+    """
+    try:
+        outlier_indices = _get_outlier_indices(data, min_samples, eps, time_window, del_zero_val, reg_smooth)
+        return len(outlier_indices) / len(data) * 100
+    except ZeroDivisionError:
+        return None
+
+
 OUTLIERS_REMOVE = remove_outliers
