@@ -2,14 +2,13 @@
 import numpy as np
 
 from indsl.resample.auto_align import auto_align
-
-# Exponents and logarithms
 from indsl.type_check import check_types
 
 
 def exp(x):
-    """Exp
-    Calculates the exponential of a time series
+    """Exp.
+
+    Calculates the exponential of a time series.
 
     Args:
         x: time-series
@@ -21,8 +20,9 @@ def exp(x):
 
 
 def log(x):
-    """Ln
-    Calculates the natural logarithm of a time series
+    """Ln.
+
+    Calculates the natural logarithm of a time series.
 
     Args:
         x: time-series
@@ -34,8 +34,9 @@ def log(x):
 
 
 def log2(x):
-    """Log base 2
-    Calculates the logarithm with base 2 of a time series
+    """Log base 2.
+
+    Calculates the logarithm with base 2 of a time series.
 
     Args:
         x: time-series
@@ -47,8 +48,9 @@ def log2(x):
 
 
 def log10(x):
-    """Log base 10
-    Calculates the logarithm with base 10 of a time series
+    """Log base 10.
+
+    Calculates the logarithm with base 10 of a time series.
 
     Args:
         x: time-series
@@ -61,8 +63,9 @@ def log10(x):
 
 @check_types
 def logn(x, base, align_timesteps: bool = False):
-    """Log, any base
-    Calculates the logarithm with base “n” of a time series
+    """Log, any base.
+
+    Calculates the logarithm with base “n” of a time series.
 
     Args:
         x: Input time-series or number
