@@ -5,43 +5,38 @@ import pandas as pd
 from numba import njit, prange
 from scipy.integrate import cumulative_trapezoid
 
+from indsl import versioning
 from indsl.exceptions import UserValueError
-from indsl.ts_utils.ts_utils import granularity_to_ms
 from indsl.type_check import check_types
+from indsl.validations import validate_series_has_minimum_length, validate_series_is_not_empty
 
-
-def granularity_to_ns(granularity, time_unit):  # noqa: D103
-    if time_unit is None or time_unit.lower() != "auto":
-        granularity = time_unit
-    return granularity_to_ms(granularity) * 1e6
+from . import numerical_calculus_v1  # noqa
 
 
 @check_types
-def trapezoidal_integration(series: pd.Series, granularity: str = "1h", time_unit: str = "auto"):
+@versioning.register(version="2.0", changelog="Removed granlularity argument; updated parameter types")
+def trapezoidal_integration(series: pd.Series, time_unit: pd.Timedelta = pd.Timedelta("1 h")) -> pd.Series:
     """Integration.
 
     Cumulative integration using trapezoidal rule with an optional user-defined time unit.
 
     Args:
         series: Time series.
-        granularity: Granularity.
-            Current granularity for the chart on-screen (auto-given).
         time_unit: Frequency.
-            User defined granularity to potentially override unit of time.
-            Accepts integer followed by time unit string (s|m|h|d). For example: '1s', '5m', '3h' or '1d'.
+            User defined granularity to potentially override unit of time. Defaults to 1 h.
+            Accepts integer followed by time unit string (ms|s|m|h|d). For example: '1s', '5m', '3h' or '1d'.
 
     Returns:
         pandas.Series: Cumulative integral.
     """
-    if len(series) < 1:
-        raise UserValueError(f"Expected series to be of length > 0, got length {len(series)}")
-    gran_ns = granularity_to_ns(granularity, time_unit)
-    arr = cumulative_trapezoid(series, series.index.view(np.int64) / gran_ns, initial=0.0)
+    validate_series_is_not_empty(series)
+    arr = cumulative_trapezoid(series, series.index.view(np.int64) / time_unit.value, initial=0.0)
     return pd.Series(arr, index=series.index)
 
 
 @check_types
-def differentiate(series: pd.Series, granularity: str = "1h", time_unit: str = "auto"):
+@versioning.register(version="2.0", changelog="Removed granlularity argument; updated parameter types")
+def differentiate(series: pd.Series, time_unit: pd.Timedelta = pd.Timedelta("1h")) -> pd.Series:
     """Differentiation.
 
     Differentiation (finite difference) using a second-order accurate numerical method (central difference).
@@ -49,19 +44,15 @@ def differentiate(series: pd.Series, granularity: str = "1h", time_unit: str = "
 
     Args:
         series: Time series.
-        granularity: Granularity.
-            Current granularity for the chart on-screen (auto-given).
         time_unit: Frequency.
-            User defined granularity to potentially override unit of time.
-            Accepts integer followed by time unit string (s|m|h|d). For example: '1s', '5m', '3h' or '1d'.
+            User defined granularity to potentially override unit of time. Defaults to 1 h.
+            Accepts integer followed by time unit string (ms|s|m|h|d). For example: '1s', '5m', '3h' or '1d'.
 
     Returns:
         pandas.Series: First order derivative.
     """
-    if len(series) < 2:
-        raise UserValueError(f"Expected series to be of length > 1, got length {len(series)}")
-    gran_ns = granularity_to_ns(granularity, time_unit)
-    arr = np.gradient(series, series.index.view(np.int64) / gran_ns)
+    validate_series_has_minimum_length(series, 2)
+    arr = np.gradient(series, series.index.view(np.int64) / time_unit.value)
     return pd.Series(arr, index=series.index)
 
 
@@ -97,7 +88,7 @@ def integrate_windows(
     """Integrate the windows.
 
     Performs the integration, through the trapezoidal- or midpoint-method.
-    Since all the from and to window indexes are available and all inputs are np.ndarrays this is parallelized and sped up with numba.
+    Since all the from and to window indexes are available and all inputs are np.ndarrays, this is parallelized and sped up with numba.
 
     Args:
         values: Values to integrate corrected to the integrand rate.
@@ -156,8 +147,7 @@ def sliding_window_integration(
     Returns:
         pandas.Series: Time series
     """
-    if len(series) < 1:
-        raise UserValueError(f"Expected series to be of length > 0, got length {len(series)}")
+    validate_series_is_not_empty(series)
 
     if max(series.index) - min(series.index) <= window_length:
         raise UserValueError("Integration time window length too long compared to the time window of the dataset.")
