@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 
 from datetime import datetime, timedelta
 from typing import List, Literal, Optional, Tuple, Union
@@ -53,7 +53,7 @@ def floor(x):
 def ceil(x):
     """Round up.
 
-    Rounds a time series up to the nearest integer greater than or
+    Rounds up a time series to the nearest integer greater than or
     equal to the current value.
 
     Args:
@@ -82,7 +82,7 @@ def sign(x):
 # Clipping functions
 @check_types
 def clip(x, low: float = -np.inf, high: float = np.inf):
-    """Clip(low, high).
+    """Clip (low, high).
 
     Given an interval, values of the time series outside the
     interval are clipped to the interval edges.
@@ -104,7 +104,7 @@ def clip(x, low: float = -np.inf, high: float = np.inf):
 def maximum(x1, x2, align_timesteps: bool = False):
     """Element-wise maximum.
 
-    Computes the maximum value of two timeseries or
+    Computes the maximum value of two time series or
     numbers.
 
     Args:
@@ -124,7 +124,7 @@ def maximum(x1, x2, align_timesteps: bool = False):
 def minimum(x1, x2, align_timesteps: bool = False):
     """Element-wise minimum.
 
-    Computes the minimum value of two timeseries.
+    Computes the minimum value of two time series.
 
     Args:
         x1: First time series or number
@@ -164,7 +164,7 @@ def union(series1: pd.Series, series2: pd.Series) -> pd.Series:
 def bin_map(x1, x2, align_timesteps: bool = False):
     """Element-wise greater-than.
 
-    Maps to a binary array by checking if one timeseries is greater than another
+    Maps to a binary array by checking if one time series is greater than another.
 
     Args:
         x1: First time series or number
@@ -297,18 +297,25 @@ def replace(series: pd.Series, to_replace: Optional[List[float]] = None, value:
 
 
 @check_types
-def remove(series: pd.Series, to_remove: Optional[List[float]] = None):
+def remove(
+    series: pd.Series,
+    to_remove: Optional[List[float]] = None,
+    range_from: Optional[float] = None,
+    range_to: Optional[float] = None,
+):
     """Remove.
 
-    Remove values in a time series. The values to remove should be a
-    semicolon-separated list. Undefined and infinity values can be replaced by
-    using nan, inf and -inf (e.g. 1.0, 5, inf, -inf, 20, nan).
+    Remove specific values or a range of values from a time series.
 
     Args:
         series: Time series
-        to_remove: Remove
+        to_remove: Values
             List of values to remove. The values must be seperated by semicolons. Infinity and undefined values can be
-            replaced by using the keywords inf, -inf and nan.
+            replaced by using the keywords inf, -inf and nan. If empty, which is the default, all values are kept.
+        range_from: Range start
+            Only values above this parameter will be kept. If empty, which is the default, this range filter is deactivated.
+        range_to: Range end
+            Only values above this parameter will be kept. If empty, which is the default, the range filter is deactivated.
 
     Returns:
         pd.Series: time series
@@ -317,9 +324,13 @@ def remove(series: pd.Series, to_remove: Optional[List[float]] = None):
         UserTypeError: series is not a time series
         UserTypeError: to_remove is not a list
     """
-    if to_remove is None:
-        return series
-    return series[~series.isin(to_remove)]
+    if to_remove is not None:
+        series = series[~series.isin(to_remove)]
+    if range_from is not None:
+        series = series[series >= range_from]
+    if range_to is not None:
+        series = series[series <= range_to]
+    return series
 
 
 @check_types
@@ -477,9 +488,9 @@ def normality_assumption_test(
 
 
 def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater") -> np.array:
-    """Z-scores Test.
+    """Z-scores test.
 
-    This functions performs a z-scores test given a cutoff value and returns a binary time series.
+    This functions performs a z-scores test given a cut-off value and returns a binary time series.
 
     Args:
         x: Data values.
@@ -487,8 +498,8 @@ def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater"
             Number of standard deviations from the mean.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the z-scores are greater than the cutoff
-                "less": the function will check if the z-scores are less than the cutoff
+                "greater": the function will check if the z-scores are greater than the cut-off
+                "less": the function will check if the z-scores are less than the cut-off
 
     Returns:
          np.array: Binary np.array with the results of the test.
@@ -505,17 +516,17 @@ def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater"
 def modified_z_scores_test(
     x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater"
 ) -> np.array:
-    """Z-scores Test.
+    """Z-scores test.
 
-    This functions performs a modified z-scores test given a cutoff value and returns a binary time series.
+    This functions performs a modified z-scores test given a cut-off value and returns a binary time series.
 
     Args:
         x: Data values.
         cutoff: Cut-off value.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the modified z-scores are greater than the cutoff
-                "less": the function will check if the modified z-scores are less than the cutoff
+                "greater": the function will check if the modified z-scores are greater than the cut-off
+                "less": the function will check if the modified z-scores are less than the cut-off
 
     Returns:
          np.array: Binary np.array with the results of the test.
@@ -533,17 +544,17 @@ def modified_z_scores_test(
 def iqr_test(
     x: np.array, limit: Literal["upper", "lower"] = "upper", direction: Literal["greater", "less"] = "greater"
 ) -> np.array:
-    """Z-scores Test.
+    """Z-scores test.
 
     This functions performs a iqr test and returns a binary time series.
 
     Args:
         x: Data values.
-        limit: Cut off limit.
+        limit: Cut-off limit.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the values are greater than the cutoff limit.
-                "less": the function will check if the values are less than the cutoff limit.
+                "greater": the function will check if the values are greater than the cut-off limit.
+                "less": the function will check if the values are less than the cut-off limit.
 
     Returns:
          np.array: Binary np.array with the results of the test.
@@ -571,8 +582,8 @@ def threshold_test(x: np.array, cutoff: float, direction: Literal["greater", "le
         cutoff: Cut-off value.
         direction: Direction of the test.
             Options:
-                "greater": the function will check if the values are greater than the cutoff limit.
-                "less": the function will check if the values are less than the cutoff limit.
+                "greater": the function will check if the values are greater than the cut-off limit.
+                "less": the function will check if the values are less than the cut-off limit.
 
     Returns:
          np.array: Binary np.array with the results of the test.
