@@ -6,7 +6,7 @@ from indsl.exceptions import UserTypeError
 
 
 def error_handling(operation):
-    """Decorator that catches TypeError and wraps to inDSL specific error"""
+    """Decorator that catches TypeError and wraps to inDSL specific error."""
 
     @wraps(operation)
     def wrapper(*args, **kwargs):
@@ -19,9 +19,10 @@ def error_handling(operation):
 
 
 def check_types(operation):
-    """Decorator to check types of inputs and outputs of a function
+    """Decorator to check types of inputs and outputs of a function.
 
-    Decorator uses typeguard library to validate arguments of a function,
-    and then wraps a TypeError to UserTypeError which is specific for inDSL library
+    Decorator uses typeguard library to validate arguments of a
+    function, and then wraps a TypeError to UserTypeError which is
+    specific for inDSL library
     """
     return error_handling(typechecked(operation))
